Class: unique_key - LinkML Model

# Class: unique_key

a collection of slots whose values uniquely identify an instance of a class

URI: linkml:UniqueKey

## Uses Mixin

- mixin: Extensible - mixin for classes that support extension
- mixin: Annotatable - mixin for classes that support annotations

## Referenced by Class

- ClassDefinition unique_keys 0..* UniqueKey

## Attributes

### Own

- unique_key_slots 1..*
  - Description: list of slot names that form a key
  - Range: SlotDefinition

### Mixed in from extensible:

- extensions 0..*
  - Description: a tag/text tuple attached to an arbitrary element
  - Range: Extension

### Mixed in from annotatable:

- annotations 0..*
  - Description: a collection of tag/text tuples with the semantics of OWL Annotation
  - Range: Annotation